@@ -1,21 +1,14 @@
 # main 75 
 # sam robson
+import warnings
+warnings.filterwarnings('ignore')
 try:
     import pyximport; pyximport.install()
     import cal
 except:
     from alacorder import alac as cal
-import glob
-import inspect
-import math
-import os
-import re
 import sys
-import time
-import warnings
-import PyPDF2
 import click
-import numpy as np
 import pandas as pd
 
 pd.set_option("mode.chained_assignment", None)
@@ -29,25 +22,27 @@ pd.set_option('display.max_rows', 100)
 @click.command()
 @click.option('--input-path', '-in', required=True, type=click.Path(), prompt=cal.title(),
               help="Path to input archive or PDF directory", show_choices=False)
-@click.option('--output-path', '-out', prompt=cal.both(), type=click.Path(),
-              help="Path to output table (.xls, .xlsx, .csv, .json, .dta) or archive (.pkl.xz)", show_choices=False)
-@click.option('--count', '-c', default=0, help='Max cases to pull from input', show_default=False)
-@click.option('--table', '-t', help="Table export choice (cases, fees, charges, disposition, filing)")
-@click.option('--overwrite', '-o', default=False, help="Overwrite output path if exists", is_flag=True,
-              show_default=False)
-@click.option('--launch', default=False, is_flag=True, help="Launch export in default application", show_default=False)
-@click.option('--dedupe', '-dd', default=False, is_flag=True, help="Remove duplicate cases from input archive")
-@click.option('--log / --no-log', default=True, is_flag=True, help="Print outputs to console upon completion")
-@click.option('--no-write', default=False, is_flag=True, help="Do not export to output path", hidden=True)
-@click.option('--no-prompt', '-np', default=False, is_flag=True, help="Skip confirmation prompts")
-@click.option('--debug', default=False, is_flag=True, help="Prints extensive logs to console for development purposes")
-@click.option('--no-batch', default=False, is_flag=True, help="Process all inputs as one batch")
-@click.option('--compress', default=False, is_flag=True,
+@click.option('--output-path', '-out', prompt=cal.both(), required=True, type=click.Path(),
+              help="Path to output table (.xls, .xlsx, .csv, .json, .dta) or archive (.pkl.xz, .json.zip, .parquet)", show_choices=False)
+@click.option('--table', '-t', help="Table export choice (cases, fees, charges, disposition, filing, or all)")
+@click.option('--archive', '-a', is_flag=True, help="Create full text archive at output path")
+@click.option('--count', '-c', default=0, help='Total cases to pull from input', show_default=False)
+@click.option('--dedupe', '-dd', default=True, is_flag=True, help="Remove duplicate cases from archive outputs")
+@click.option('--compress','-zip', default=False, is_flag=True,
               help="Compress exported file (archives compress with or without flag)")
-def cli(input_path, output_path, count, table, overwrite, launch, dedupe, log, no_write, no_prompt, debug, no_batch,
+@click.option('--overwrite', '-o', default=False, help="Overwrite existing files at output path", is_flag=True,show_default=False)
+@click.option('--launch', '-l', default=False, is_flag=True, help="Launch export in default application", show_default=False)
+@click.option('--no-log','-nl','log', default=False, is_flag=True, help="Don't print logs or progress to console")
+@click.option('--no-write','-nw', default=False, is_flag=True, help="Do not export to output path", hidden=True)
+@click.option('--no-prompt', '-np', default=False, is_flag=True, help="Skip user input / confirmation prompts")
+@click.option('--debug','-db', default=False, is_flag=True, help="Prints extensive logs to console for development purposes")
+@click.option('--no-batch','-nb', default=False, is_flag=True, help="Process all inputs as one batch")
+def cli(input_path, output_path, count, table, archive, overwrite, launch, dedupe, log, no_write, no_prompt, debug, no_batch,
         compress):
     show_options_menu = True if table is None and no_prompt == False and count == 0 and overwrite == False and launch == False and dedupe == False and log == True and no_write == False and no_prompt == False and debug == False and no_batch == False else False
 
+    log = not log 
+
     # suppress tracebacks unless debug
     if not debug:
         sys.tracebacklimit = 0
@@ -63,7 +58,7 @@ def cli(input_path, output_path, count, table, overwrite, launch, dedupe, log, n
         raise Exception("Invalid input path!")
 
     # outputs - configure and log
-    outputs = cal.setoutputs(output_path)
+    outputs = cal.setoutputs(output_path,archive=archive)
     if debug:
         click.echo(outputs)
     if log:
@@ -76,7 +71,7 @@ def cli(input_path, output_path, count, table, overwrite, launch, dedupe, log, n
         if no_prompt:
             raise Exception("Existing file at output path! Repeat with flag --overwrite to replace file.")
         else:
-            if click.confirm(echo_yellow("Existing file at output path will be written over! Continue?", echo=False)):
+            if click.confirm(cal.echo_yellow("Existing file at output path will be written over! Continue?", echo=False)):
                 pass
             else:
                 raise Exception("Existing file at output path!")
@@ -109,27 +104,27 @@ def cli(input_path, output_path, count, table, overwrite, launch, dedupe, log, n
     if show_options_menu and not no_prompt:
         if not click.confirm("Continue with current settings?"):
             cli.main(['alacorder', '--help'], standalone_mode=False)
-            p = click.prompt('\nEnter the <option> you would like to set')
+            p = click.prompt('\nEnter the <option> you would like to set, or type \'quit\' to quit.')
             if p == "count" or p == "-c" or p == "--count":
-                count = click.prompt("Set max case count to pull from input: ", type=int)
+                count = click.prompt("Set total case count to pull from input", type=int)
             elif p == "overwrite" or p == "--overwrite" or p == "-o":
                 overwrite = click.prompt(
-                    "Should Alacorder OVERWRITE existing files at provided output file paths? [y/N]", type=bool)
+                    "Should Alacorder OVERWRITE any existing files at output file paths? [y/N]", type=bool)
             elif p == "launch" or p == "--launch":
                 launch = click.prompt("Should Alacorder attempt to launch exported files once complete? [y/N]",
                                       type=bool)
             elif p == "dedupe" or p == "--dedupe" or p == "-dd":
-                dedupe = click.prompt("Should Alacorder attempt to remove duplicate cases from outputs? [y/N]",
+                dedupe = click.prompt("Should Alacorder remove duplicate cases from outputs? [y/N]",
                                       type=bool)
-            elif p == "log" or p == "--log" or p == "no-log" or p == "--no-log":
+            elif p == "log" or p == "--log" or p == "no-log" or p == "--no-log" or p == "nl" or p == "-nl" or p == "no log":
                 log = click.prompt("Should Alacorder print logs to console? [y/N]", type=bool)
-            elif p == "no_prompt" or p == "--no-prompt" or p == "-np":
+            elif p == "no_prompt" or p == "--no-prompt" or p == "-np" or p == "np":
                 no_prompt = click.prompt("Should Alacorder proceed without prompting for user input? [y/N]", type=bool)
-            elif p == "debug" or p == "--debug" or p == "-d":
+            elif p == "debug" or p == "--debug" or p == "-db" or p == "db":
                 debug = click.prompt("Should Alacorder print detailed debug logs? [y/N]", type=bool)
-            elif p == "no_batch" or p == "--no-batch":
+            elif p == "no_batch" or p == "--no-batch" or p == "-nb" or p == "nb" or p == "nobatch" or p == "no batch":
                 no_batch = click.prompt("Should Alacorder process all cases in one batch? [y/N]", type=bool)
-            elif p == "compress" or p == "--compress":
+            elif p == "compress" or p == "--compress" or p == "-zip" or p == "zip":
                 compress = click.prompt("Should Alacorder compress exports? [y/N]", type=bool)
             elif p == "table" or p == "--table" or p == "-t":
                 pick = click.prompt(cal.pick_table())  # add str
